@@ -329,7 +329,10 @@ class Environment extends Base {
     // Pass forwardErrorToEnvironment to generators.
     this.sharedOptions.forwardErrorToEnvironment = false;
 
-    this.repository = new YeomanRepository(this.options.yeomanRepository);
+    this.repository = new YeomanRepository({
+      repositoryPath: this.options.yeomanRepository,
+      arboristRegister: this.options.arboristRegister
+    });
 
     if (!this.options.experimental) {
       for (const value of process.argv) {
@@ -688,6 +691,7 @@ class Environment extends Base {
     if (typeof Generator.default === 'function') {
       Generator.default.resolved = meta.resolved;
       Generator.default.namespace = meta.namespace;
+      Generator.default.packagePath = meta.packagePath;
       return Generator.default;
     }
     if (typeof Generator.createGenerator === 'function') {
@@ -696,11 +700,13 @@ class Environment extends Base {
         return maybeGenerator.then(Gen => {
           Gen.resolved = meta.resolved;
           Gen.namespace = meta.namespace;
+          Gen.packagePath = meta.packagePath;
           return Gen;
         });
       }
       maybeGenerator.resolved = meta.resolved;
       maybeGenerator.namespace = meta.namespace;
+      maybeGenerator.packagePath = meta.packagePath;
       return maybeGenerator;
     }
     if (typeof Generator !== 'function') {
@@ -1206,7 +1212,7 @@ class Environment extends Base {
   applyTransforms(transformStreams, options = {}) {
     const {
       stream = this.sharedFs.stream(),
-      name = 'Tranforming'
+      name = 'Transforming'
     } = options;
 
     let {log = true} = options;
